@@ -3,14 +3,12 @@ from jirafs.plugin import CommandPlugin
 
 class Command(CommandPlugin):
     """ Print a diff of locally-changed files """
-    MIN_VERSION = '1.0a1'
-    MAX_VERSION = '1.99.99'
 
-    def handle(self, folder, **kwargs):
-        return self.diff(folder)
+    MIN_VERSION = "2.0.0"
+    MAX_VERSION = "3.0.0"
 
-    def diff(self, folder):
-        result = folder.run_git_command('diff')
+    def main(self, folder, **kwargs):
+        result = folder.run_git_command("diff")
         if result:
             result = result.strip()
         print(result)
