@@ -5,13 +5,11 @@ from jirafs.plugin import CommandPlugin
 
 class Command(CommandPlugin):
     """ Print the log for this issue """
-    MIN_VERSION = '1.0a1'
-    MAX_VERSION = '1.99.99'
 
-    def handle(self, folder, **kwargs):
-        return self.log(folder)
+    MIN_VERSION = "2.0.0"
+    MAX_VERSION = "3.0.0"
 
-    def log(self, folder):
+    def main(self, folder, **kwargs):
         results = folder.get_log()
         pydoc.pager(results)
         return results
