@@ -5,11 +5,9 @@ from jirafs.plugin import CommandPlugin
 
 class Command(CommandPlugin):
     """ Open the current ticketfolder's issue in your web browser """
-    MIN_VERSION = '1.0a1'
-    MAX_VERSION = '1.99.99'
 
-    def handle(self, folder, **kwargs):
-        return self.open(folder)
+    MIN_VERSION = "2.0.0"
+    MAX_VERSION = "3.0.0"
 
-    def open(self, folder):
+    def main(self, folder, *args, **kwargs):
         return webbrowser.open(folder.cached_issue.permalink())
