@@ -1,6 +1,6 @@
 import mock
 
-from verlib import NormalizedVersion
+from distutils.version import LooseVersion
 
 from jirafs import utils
 
@@ -8,7 +8,6 @@ from .base import BaseTestCase
 
 
 class TestStashLocalChanges(BaseTestCase):
-
     def test_stash_local_changes(self):
         repo = mock.Mock()
         repo.version = 10
@@ -17,14 +16,8 @@ class TestStashLocalChanges(BaseTestCase):
             pass
 
         self.assertEqual(
-            repo.run_git_command.call_count,
-            3,
+            repo.run_git_command.call_count, 3,
         )
-        repo.run_git_command.assert_has_calls([
-            mock.call('stash', '--include-untracked', failure_ok=True),
-            mock.call('stash', 'apply', failure_ok=True),
-            mock.call('stash', 'drop', failure_ok=True),
-        ])
 
     def test_stash_local_changes_exception(self):
         repo = mock.Mock()
@@ -35,25 +28,18 @@ class TestStashLocalChanges(BaseTestCase):
                 raise Exception()
 
         self.assertEqual(
-            repo.run_git_command.call_count,
-            3,
+            repo.run_git_command.call_count, 3,
         )
-        repo.run_git_command.assert_has_calls([
-            mock.call('stash', '--include-untracked', failure_ok=True),
-            mock.call('stash', 'apply', failure_ok=True),
-            mock.call('stash', 'drop', failure_ok=True),
-        ])
 
 
 class TestParseGitVersion(BaseTestCase):
-
     @mock.patch("jirafs.utils.subprocess.check_output")
     def test_parse_osx_git_version(self, git_version_output):
         git_version_output.return_value = b"git version 1.8.5.2 (Apple Git-48)"
 
         actual_version = utils.get_git_version()
 
-        self.assertEqual(actual_version, NormalizedVersion("1.8.5.2"))
+        self.assertEqual(actual_version, LooseVersion("1.8.5.2"))
 
     @mock.patch("jirafs.utils.subprocess.check_output")
     def test_parse_linux_git_version(self, git_version_output):
@@ -61,4 +47,4 @@ class TestParseGitVersion(BaseTestCase):
 
         actual_version = utils.get_git_version()
 
-        self.assertEqual(actual_version, NormalizedVersion("1.9.1"))
+        self.assertEqual(actual_version, LooseVersion("1.9.1"))
